buzz method
void
buzz()
Plays the buzz preset without awaiting the platform call.
Implementation
void buzz() => _presets.playSync('buzz');
Plays the buzz preset without awaiting the platform call.
void buzz() => _presets.playSync('buzz');