explosion method
void
explosion()
Plays the explosion preset without awaiting the platform call.
Implementation
void explosion() => _presets.playSync('explosion');
Plays the explosion preset without awaiting the platform call.
void explosion() => _presets.playSync('explosion');