pendulum method
void
pendulum()
Plays the pendulum preset without awaiting the platform call.
Implementation
void pendulum() => _presets.playSync('pendulum');
Plays the pendulum preset without awaiting the platform call.
void pendulum() => _presets.playSync('pendulum');