ping method
void
ping()
Plays the ping preset without awaiting the platform call.
Implementation
void ping() => _presets.playSync('ping');
Plays the ping preset without awaiting the platform call.
void ping() => _presets.playSync('ping');