push method
void
push()
Plays the push preset without awaiting the platform call.
Implementation
void push() => _presets.playSync('push');
Plays the push preset without awaiting the platform call.
void push() => _presets.playSync('push');