rustle method
void
rustle()
Plays the rustle preset without awaiting the platform call.
Implementation
void rustle() => _presets.playSync('rustle');
Plays the rustle preset without awaiting the platform call.
void rustle() => _presets.playSync('rustle');