snap method
void
snap()
Plays the snap preset without awaiting the platform call.
Implementation
void snap() => _presets.playSync('snap');
Plays the snap preset without awaiting the platform call.
void snap() => _presets.playSync('snap');