trigger method
void
trigger()
Plays the trigger preset without awaiting the platform call.
Implementation
void trigger() => _presets.playSync('trigger');
Plays the trigger preset without awaiting the platform call.
void trigger() => _presets.playSync('trigger');