vortex method
void
vortex()
Plays the vortex preset without awaiting the platform call.
Implementation
void vortex() => _presets.playSync('vortex');
Plays the vortex preset without awaiting the platform call.
void vortex() => _presets.playSync('vortex');