wave method
void
wave()
Plays the wave preset without awaiting the platform call.
Implementation
void wave() => _presets.playSync('wave');
Plays the wave preset without awaiting the platform call.
void wave() => _presets.playSync('wave');