PulsarPlatform class abstract
Platform interface for the Pulsar haptics plugin.
Implement this class to provide a custom platform implementation. The default implementation uses MethodChannelPulsar.
- Inheritance
-
- Object
- PlatformInterface
- PulsarPlatform
- Implementers
Constructors
- PulsarPlatform()
- Creates a PulsarPlatform instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canPlayHaptics(
) → Future< bool> -
clearCache(
) → Future< void> -
enableCache(
bool state) → Future< void> -
enableHaptics(
bool state) → Future< void> -
enableImpulseCompositionMode(
bool state) → Future< void> -
enableSound(
bool state) → Future< void> -
forceHapticsSupportLevel(
HapticSupport level) → Future< void> -
hapticSupport(
) → Future< HapticSupport> -
isCacheEnabled(
) → Future< bool> -
isHapticsEnabled(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patternParsePattern(
PatternData data, {int? composerId}) → Future< int> -
patternPlay(
int composerId) → Future< void> -
patternPlayAudioOnly(
int composerId) → Future< void> -
patternPlayPattern(
PatternData data, {int? composerId}) → Future< int> -
patternRelease(
int composerId) → Future< void> -
patternStop(
int composerId) → Future< void> -
play(
String name) → Future< void> -
preloadPreset(
String presetName) → Future< void> -
preloadPresets(
List< String> presetNames) → Future<void> -
presetExists(
String presetName) → Future< bool> -
realtimeIsActive(
{RealtimeComposerStrategy? strategy}) → Future< bool> -
realtimePlayDiscrete(
double amplitude, double frequency, {RealtimeComposerStrategy? strategy}) → Future< void> -
realtimeSet(
double amplitude, double frequency, {RealtimeComposerStrategy? strategy}) → Future< void> -
realtimeStop(
{RealtimeComposerStrategy? strategy}) → Future< void> -
setRealtimeComposerStrategy(
RealtimeComposerStrategy strategy) → Future< void> -
shutDownEngine(
) → Future< void> -
stopHaptics(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ PulsarPlatform
-
getter/setter pair