AdaptivePresetCallback class final

An AdaptivePresetConfig that invokes a callback when played.

Inheritance

Constructors

AdaptivePresetCallback(Future<void> play())
Creates an AdaptivePresetCallback with the given play callback.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
play Future<void> Function()
Callback invoked when AdaptiveHaptics.play is called.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited