ContinuousPattern class
A continuous haptic pattern defined by amplitude and frequency curves.
Constructors
-
ContinuousPattern({required List<
ValuePoint> amplitude, required List<ValuePoint> frequency}) -
Creates a ContinuousPattern with the given
amplitudeandfrequencycurves.const
Properties
-
amplitude
→ List<
ValuePoint> -
Amplitude curve: list of ValuePoint controlling intensity over time.
final
-
frequency
→ List<
ValuePoint> -
Frequency curve: list of ValuePoint controlling sharpness over time.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited