DiscretePoint class
Constructors
- DiscretePoint({required double time, required double amplitude, required double frequency})
-
Creates a DiscretePoint at
timems withamplitudeandfrequency.const
Properties
- amplitude → double
-
Event intensity in the range 0.0–1.0.
final
- frequency → double
-
Event sharpness in the range 0.0–1.0.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → double
-
Time offset in milliseconds from the start of the pattern.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited