discretePattern property
The list of discrete haptic events layered on top of the continuous curve.
Implementation
final List<DiscretePoint> discretePattern;
The list of discrete haptic events layered on top of the continuous curve.
final List<DiscretePoint> discretePattern;