RealtimeComposerStrategy enum

Android-only haptic composition strategy. Ordinal values match the Android RealtimeComposerStrategy enum order.

Inheritance
Available extensions

Values

envelope → const RealtimeComposerStrategy

Uses VibrationEffect amplitude-envelope composition.

primitiveTick → const RealtimeComposerStrategy

Uses a repeating tick primitive for continuous feedback.

primitiveComplex → const RealtimeComposerStrategy

Uses complex primitives for richer continuous feedback.

envelopeWithDiscretePrimitives → const RealtimeComposerStrategy

Combines an amplitude envelope with discrete primitives.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RealtimeComposerStrategy>
A constant List of the values in this enum, in order of their declaration.