ValuePoint class

A point in a continuous haptic curve. time is in milliseconds. value is 0.0–1.0.

Constructors

ValuePoint({required double time, required double value})
Creates a ValuePoint with the given time (ms) and value (0.0–1.0).
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time double
Time offset in milliseconds from the start of the pattern.
final
value double
Amplitude or frequency value in the range 0.0–1.0.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited