PulsarPresets class
Provides access to Pulsar's 200+ built-in haptic presets.
Call any named method to play that preset immediately, or use play with a preset name string.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
afterglow(
) → Future< void> - Plays the afterglow preset.
-
aftershock(
) → Future< void> - Plays the aftershock preset.
-
alarm(
) → Future< void> - Plays the alarm preset.
-
anvil(
) → Future< void> - Plays the anvil preset.
-
applause(
) → Future< void> - Plays the applause preset.
-
ascent(
) → Future< void> - Plays the ascent preset.
-
balloonPop(
) → Future< void> - Plays the balloon-pop preset.
-
barrage(
) → Future< void> - Plays the barrage preset.
-
bassDrop(
) → Future< void> - Plays the bass-drop preset.
-
batter(
) → Future< void> - Plays the batter preset.
-
bellToll(
) → Future< void> - Plays the bell-toll preset.
-
blip(
) → Future< void> - Plays the blip preset.
-
bloom(
) → Future< void> - Plays the bloom preset.
-
bongo(
) → Future< void> - Plays the bongo preset.
-
boulder(
) → Future< void> - Plays the boulder preset.
-
breakingWave(
) → Future< void> - Plays the breaking-wave preset.
-
breath(
) → Future< void> - Plays the breath preset.
-
buildup(
) → Future< void> - Plays the buildup preset.
-
burst(
) → Future< void> - Plays the burst preset.
-
buzz(
) → Future< void> - Plays the buzz preset.
-
cadence(
) → Future< void> - Plays the cadence preset.
-
cameraShutter(
) → Future< void> - Plays the camera-shutter preset.
-
canter(
) → Future< void> - Plays the canter preset.
-
cascade(
) → Future< void> - Plays the cascade preset.
-
castanets(
) → Future< void> - Plays the castanets preset.
-
catPaw(
) → Future< void> - Plays the cat-paw preset.
-
charge(
) → Future< void> - Plays the charge preset.
-
chime(
) → Future< void> - Plays the chime preset.
-
chip(
) → Future< void> - Plays the chip preset.
-
chirp(
) → Future< void> - Plays the chirp preset.
-
clamor(
) → Future< void> - Plays the clamor preset.
-
clasp(
) → Future< void> - Plays the clasp preset.
-
cleave(
) → Future< void> - Plays the cleave preset.
-
coil(
) → Future< void> - Plays the coil preset.
-
coinDrop(
) → Future< void> - Plays the coin-drop preset.
-
combinationLock(
) → Future< void> - Plays the combination-lock preset.
-
crescendo(
) → Future< void> - Plays the crescendo preset.
-
dewdrop(
) → Future< void> - Plays the dewdrop preset.
-
dirge(
) → Future< void> - Plays the dirge preset.
-
dissolve(
) → Future< void> - Plays the dissolve preset.
-
dogBark(
) → Future< void> - Plays the dog-bark preset.
-
drone(
) → Future< void> - Plays the drone preset.
-
enableCache(
bool state) → Future< void> -
Enable or disable preset caching. Mirrors
PresetsWrapper.enableCache. -
engineRev(
) → Future< void> - Plays the engine-rev preset.
-
exhale(
) → Future< void> - Plays the exhale preset.
-
explosion(
) → Future< void> - Plays the explosion preset.
-
fadeOut(
) → Future< void> - Plays the fade-out preset.
-
fanfare(
) → Future< void> - Plays the fanfare preset.
-
feather(
) → Future< void> - Plays the feather preset.
-
finale(
) → Future< void> - Plays the finale preset.
-
fingerDrum(
) → Future< void> - Plays the finger-drum preset.
-
firecracker(
) → Future< void> - Plays the firecracker preset.
-
fizz(
) → Future< void> - Plays the fizz preset.
-
flare(
) → Future< void> - Plays the flare preset.
-
flick(
) → Future< void> - Plays the flick preset.
-
flinch(
) → Future< void> - Plays the flinch preset.
-
flourish(
) → Future< void> - Plays the flourish preset.
-
flurry(
) → Future< void> - Plays the flurry preset.
-
flush(
) → Future< void> - Plays the flush preset.
-
gallop(
) → Future< void> - Plays the gallop preset.
-
gavel(
) → Future< void> - Plays the gavel preset.
-
getByName(
String name) → Future< PulsarPreset?> -
Returns a lightweight handle to the preset with
name, ornullif no preset matches. Mirrors the nativegetByNameAPI. -
glitch(
) → Future< void> - Plays the glitch preset.
-
guitarStrum(
) → Future< void> - Plays the guitar-strum preset.
-
hail(
) → Future< void> - Plays the hail preset.
-
hammer(
) → Future< void> - Plays the hammer preset.
-
heartbeat(
) → Future< void> - Plays the heartbeat preset.
-
herald(
) → Future< void> - Plays the herald preset.
-
hoofBeat(
) → Future< void> - Plays the hoof-beat preset.
-
ignition(
) → Future< void> - Plays the ignition preset.
-
impact(
) → Future< void> - Plays the impact preset.
-
isCacheEnabled(
) → Future< bool> -
Whether preset caching is enabled. Mirrors
PresetsWrapper.isCacheEnabled. -
jolt(
) → Future< void> - Plays the jolt preset.
-
keyboardMechanical(
) → Future< void> - Plays the mechanical-keyboard preset.
-
keyboardMembrane(
) → Future< void> - Plays the membrane-keyboard preset.
-
knell(
) → Future< void> - Plays the knell preset.
-
knock(
) → Future< void> - Plays the knock preset.
-
lament(
) → Future< void> - Plays the lament preset.
-
latch(
) → Future< void> - Plays the latch preset.
-
lighthouse(
) → Future< void> - Plays the lighthouse preset.
-
lilt(
) → Future< void> - Plays the lilt preset.
-
lock(
) → Future< void> - Plays the lock preset.
-
lope(
) → Future< void> - Plays the lope preset.
-
march(
) → Future< void> - Plays the march preset.
-
metronome(
) → Future< void> - Plays the metronome preset.
-
murmur(
) → Future< void> - Plays the murmur preset.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nudge(
) → Future< void> - Plays the nudge preset.
-
passingCar(
) → Future< void> - Plays the passing-car preset.
-
patter(
) → Future< void> - Plays the patter preset.
-
peal(
) → Future< void> - Plays the peal preset.
-
peck(
) → Future< void> - Plays the peck preset.
-
pendulum(
) → Future< void> - Plays the pendulum preset.
-
ping(
) → Future< void> - Plays the ping preset.
-
pip(
) → Future< void> - Plays the pip preset.
-
piston(
) → Future< void> - Plays the piston preset.
-
play(
String name) → Future< void> -
Play a preset by its
namestring. Prefer the named shorthand methods for compile-time safety (e.g. systemImpactMedium, heartbeat). -
plink(
) → Future< void> - Plays the plink preset.
-
plummet(
) → Future< void> - Plays the plummet preset.
-
plunk(
) → Future< void> - Plays the plunk preset.
-
poke(
) → Future< void> - Plays the poke preset.
-
pound(
) → Future< void> - Plays the pound preset.
-
powerDown(
) → Future< void> - Plays the power-down preset.
-
preloadPresetByName(
String name) → Future< void> -
Preload a single preset by name. Mirrors
PresetsWrapper.preloadPresetByName. -
preloadPresetByNames(
List< String> names) → Future<void> -
Preload many presets by name. Mirrors
PresetsWrapper.preloadPresetByNames. -
propel(
) → Future< void> - Plays the propel preset.
-
pulse(
) → Future< void> - Plays the pulse preset.
-
pummel(
) → Future< void> - Plays the pummel preset.
-
push(
) → Future< void> - Plays the push preset.
-
radar(
) → Future< void> - Plays the radar preset.
-
rain(
) → Future< void> - Plays the rain preset.
-
ramp(
) → Future< void> - Plays the ramp preset.
-
rap(
) → Future< void> - Plays the rap preset.
-
ratchet(
) → Future< void> - Plays the ratchet preset.
-
rebound(
) → Future< void> - Plays the rebound preset.
-
resetCache(
) → Future< void> -
Clear any cached preset data. Mirrors
PresetsWrapper.resetCache. -
ripple(
) → Future< void> - Plays the ripple preset.
-
rivet(
) → Future< void> - Plays the rivet preset.
-
rustle(
) → Future< void> - Plays the rustle preset.
-
shockwave(
) → Future< void> - Plays the shockwave preset.
-
snap(
) → Future< void> - Plays the snap preset.
-
sonar(
) → Future< void> - Plays the sonar preset.
-
spark(
) → Future< void> - Plays the spark preset.
-
spin(
) → Future< void> - Plays the spin preset.
-
stagger(
) → Future< void> - Plays the stagger preset.
-
stamp(
) → Future< void> - Plays the stamp preset.
-
stampede(
) → Future< void> - Plays the stampede preset.
-
stomp(
) → Future< void> - Plays the stomp preset.
-
stoneSkip(
) → Future< void> - Plays the stone-skip preset.
-
strike(
) → Future< void> - Plays the strike preset.
-
summon(
) → Future< void> - Plays the summon preset.
-
surge(
) → Future< void> - Plays the surge preset.
-
sway(
) → Future< void> - Plays the sway preset.
-
sweep(
) → Future< void> - Plays the sweep preset.
-
swell(
) → Future< void> - Plays the swell preset.
-
syncopate(
) → Future< void> - Plays the syncopate preset.
-
systemCalendarDate(
) → Future< void> - Plays the system calendar-date-picker haptic.
-
systemClockTick(
) → Future< void> - Plays the system clock-tick haptic.
-
systemConfirm(
) → Future< void> - Plays the system confirm haptic.
-
systemContextClick(
) → Future< void> - Plays the system context-click haptic.
-
systemDragCrossing(
) → Future< void> - Plays the system drag-crossing haptic.
-
systemDragStart(
) → Future< void> - Plays the system drag-start haptic.
-
systemEdgeRelease(
) → Future< void> - Plays the system edge-release haptic.
-
systemEdgeSqueeze(
) → Future< void> - Plays the system edge-squeeze haptic.
-
systemEffectClick(
) → Future< void> - Plays the system single-click effect haptic.
-
systemEffectDoubleClick(
) → Future< void> - Plays the system double-click effect haptic.
-
systemEffectHeavyClick(
) → Future< void> - Plays the system heavy-click effect haptic.
-
systemEffectTick(
) → Future< void> - Plays the system tick effect haptic.
-
systemGestureEnd(
) → Future< void> - Plays the system gesture-end haptic.
-
systemGestureStart(
) → Future< void> - Plays the system gesture-start haptic.
-
systemImpactHeavy(
) → Future< void> - Plays the system heavy-impact haptic.
-
systemImpactLight(
) → Future< void> - Plays the system light-impact haptic.
-
systemImpactMedium(
) → Future< void> - Plays the system medium-impact haptic.
-
systemImpactRigid(
) → Future< void> - Plays the system rigid-impact haptic.
-
systemImpactSoft(
) → Future< void> - Plays the system soft-impact haptic.
-
systemKeyboardPress(
) → Future< void> - Plays the system keyboard-press haptic.
-
systemKeyboardRelease(
) → Future< void> - Plays the system keyboard-release haptic.
-
systemKeyboardTap(
) → Future< void> - Plays the system keyboard-tap haptic.
-
systemLongPress(
) → Future< void> - Plays the system long-press haptic.
-
systemNotificationError(
) → Future< void> - Plays the system error-notification haptic.
-
systemNotificationSuccess(
) → Future< void> - Plays the system success-notification haptic.
-
systemNotificationWarning(
) → Future< void> - Plays the system warning-notification haptic.
-
systemPrimitiveClick(
) → Future< void> - Plays the system primitive-click haptic.
-
systemPrimitiveLowTick(
) → Future< void> - Plays the system primitive-low-tick haptic.
-
systemPrimitiveQuickFall(
) → Future< void> - Plays the system primitive-quick-fall haptic.
-
systemPrimitiveQuickRise(
) → Future< void> - Plays the system primitive-quick-rise haptic.
-
systemPrimitiveSlowRise(
) → Future< void> - Plays the system primitive-slow-rise haptic.
-
systemPrimitiveSpin(
) → Future< void> - Plays the system primitive-spin haptic.
-
systemPrimitiveThud(
) → Future< void> - Plays the system primitive-thud haptic.
-
systemPrimitiveTick(
) → Future< void> - Plays the system primitive-tick haptic.
-
systemRelease(
) → Future< void> - Plays the system release haptic.
-
systemScrollItemFocus(
) → Future< void> - Plays the system scroll-item-focus haptic.
-
systemScrollLimit(
) → Future< void> - Plays the system scroll-limit haptic.
-
systemScrollTick(
) → Future< void> - Plays the system scroll-tick haptic.
-
systemSegmentFrequentTick(
) → Future< void> - Plays the system frequent-segment-tick haptic.
-
systemSegmentTick(
) → Future< void> - Plays the system segment-tick haptic.
-
systemSelection(
) → Future< void> - Plays the system selection-change haptic.
-
systemTextHandleMove(
) → Future< void> - Plays the system text-handle-move haptic.
-
systemToggleOff(
) → Future< void> - Plays the system toggle-off haptic.
-
systemToggleOn(
) → Future< void> - Plays the system toggle-on haptic.
-
systemVirtualKey(
) → Future< void> - Plays the system virtual-key haptic.
-
systemVirtualKeyRelease(
) → Future< void> - Plays the system virtual-key-release haptic.
-
throb(
) → Future< void> - Plays the throb preset.
-
thud(
) → Future< void> - Plays the thud preset.
-
thump(
) → Future< void> - Plays the thump preset.
-
thunder(
) → Future< void> - Plays the thunder preset.
-
thunderRoll(
) → Future< void> - Plays the thunder-roll preset.
-
tickTock(
) → Future< void> - Plays the tick-tock preset.
-
tidalSurge(
) → Future< void> - Plays the tidal-surge preset.
-
tideSwell(
) → Future< void> - Plays the tide-swell preset.
-
toString(
) → String -
A string representation of this object.
inherited
-
tremor(
) → Future< void> - Plays the tremor preset.
-
trigger(
) → Future< void> - Plays the trigger preset.
-
triumph(
) → Future< void> - Plays the triumph preset.
-
trumpet(
) → Future< void> - Plays the trumpet preset.
-
typewriter(
) → Future< void> - Plays the typewriter preset.
-
unfurl(
) → Future< void> - Plays the unfurl preset.
-
vortex(
) → Future< void> - Plays the vortex preset.
-
wane(
) → Future< void> - Plays the wane preset.
-
warDrum(
) → Future< void> - Plays the war-drum preset.
-
waterfall(
) → Future< void> - Plays the waterfall preset.
-
wave(
) → Future< void> - Plays the wave preset.
-
wisp(
) → Future< void> - Plays the wisp preset.
-
wobble(
) → Future< void> - Plays the wobble preset.
-
woodpecker(
) → Future< void> - Plays the woodpecker preset.
-
zipper(
) → Future< void> - Plays the zipper preset.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited