PulsarSyncPresets class
Fire-and-forget convenience wrapper around PulsarPresets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
afterglow(
) → void - Plays the afterglow preset without awaiting the platform call.
-
aftershock(
) → void - Plays the aftershock preset without awaiting the platform call.
-
alarm(
) → void - Plays the alarm preset without awaiting the platform call.
-
anvil(
) → void - Plays the anvil preset without awaiting the platform call.
-
applause(
) → void - Plays the applause preset without awaiting the platform call.
-
ascent(
) → void - Plays the ascent preset without awaiting the platform call.
-
balloonPop(
) → void - Plays the balloon-pop preset without awaiting the platform call.
-
barrage(
) → void - Plays the barrage preset without awaiting the platform call.
-
bassDrop(
) → void - Plays the bass-drop preset without awaiting the platform call.
-
batter(
) → void - Plays the batter preset without awaiting the platform call.
-
bellToll(
) → void - Plays the bell-toll preset without awaiting the platform call.
-
blip(
) → void - Plays the blip preset without awaiting the platform call.
-
bloom(
) → void - Plays the bloom preset without awaiting the platform call.
-
bongo(
) → void - Plays the bongo preset without awaiting the platform call.
-
boulder(
) → void - Plays the boulder preset without awaiting the platform call.
-
breakingWave(
) → void - Plays the breaking-wave preset without awaiting the platform call.
-
breath(
) → void - Plays the breath preset without awaiting the platform call.
-
buildup(
) → void - Plays the buildup preset without awaiting the platform call.
-
burst(
) → void - Plays the burst preset without awaiting the platform call.
-
buzz(
) → void - Plays the buzz preset without awaiting the platform call.
-
cadence(
) → void - Plays the cadence preset without awaiting the platform call.
-
cameraShutter(
) → void - Plays the camera-shutter preset without awaiting the platform call.
-
canter(
) → void - Plays the canter preset without awaiting the platform call.
-
cascade(
) → void - Plays the cascade preset without awaiting the platform call.
-
castanets(
) → void - Plays the castanets preset without awaiting the platform call.
-
catPaw(
) → void - Plays the cat-paw preset without awaiting the platform call.
-
charge(
) → void - Plays the charge preset without awaiting the platform call.
-
chime(
) → void - Plays the chime preset without awaiting the platform call.
-
chip(
) → void - Plays the chip preset without awaiting the platform call.
-
chirp(
) → void - Plays the chirp preset without awaiting the platform call.
-
clamor(
) → void - Plays the clamor preset without awaiting the platform call.
-
clasp(
) → void - Plays the clasp preset without awaiting the platform call.
-
cleave(
) → void - Plays the cleave preset without awaiting the platform call.
-
coil(
) → void - Plays the coil preset without awaiting the platform call.
-
coinDrop(
) → void - Plays the coin-drop preset without awaiting the platform call.
-
combinationLock(
) → void - Plays the combination-lock preset without awaiting the platform call.
-
crescendo(
) → void - Plays the crescendo preset without awaiting the platform call.
-
dewdrop(
) → void - Plays the dewdrop preset without awaiting the platform call.
-
dirge(
) → void - Plays the dirge preset without awaiting the platform call.
-
dissolve(
) → void - Plays the dissolve preset without awaiting the platform call.
-
dogBark(
) → void - Plays the dog-bark preset without awaiting the platform call.
-
drone(
) → void - Plays the drone preset without awaiting the platform call.
-
engineRev(
) → void - Plays the engine-rev preset without awaiting the platform call.
-
exhale(
) → void - Plays the exhale preset without awaiting the platform call.
-
explosion(
) → void - Plays the explosion preset without awaiting the platform call.
-
fadeOut(
) → void - Plays the fade-out preset without awaiting the platform call.
-
fanfare(
) → void - Plays the fanfare preset without awaiting the platform call.
-
feather(
) → void - Plays the feather preset without awaiting the platform call.
-
finale(
) → void - Plays the finale preset without awaiting the platform call.
-
fingerDrum(
) → void - Plays the finger-drum preset without awaiting the platform call.
-
firecracker(
) → void - Plays the firecracker preset without awaiting the platform call.
-
fizz(
) → void - Plays the fizz preset without awaiting the platform call.
-
flare(
) → void - Plays the flare preset without awaiting the platform call.
-
flick(
) → void - Plays the flick preset without awaiting the platform call.
-
flinch(
) → void - Plays the flinch preset without awaiting the platform call.
-
flourish(
) → void - Plays the flourish preset without awaiting the platform call.
-
flurry(
) → void - Plays the flurry preset without awaiting the platform call.
-
flush(
) → void - Plays the flush preset without awaiting the platform call.
-
gallop(
) → void - Plays the gallop preset without awaiting the platform call.
-
gavel(
) → void - Plays the gavel preset without awaiting the platform call.
-
glitch(
) → void - Plays the glitch preset without awaiting the platform call.
-
guitarStrum(
) → void - Plays the guitar-strum preset without awaiting the platform call.
-
hail(
) → void - Plays the hail preset without awaiting the platform call.
-
hammer(
) → void - Plays the hammer preset without awaiting the platform call.
-
heartbeat(
) → void - Plays the heartbeat preset without awaiting the platform call.
-
herald(
) → void - Plays the herald preset without awaiting the platform call.
-
hoofBeat(
) → void - Plays the hoof-beat preset without awaiting the platform call.
-
ignition(
) → void - Plays the ignition preset without awaiting the platform call.
-
impact(
) → void - Plays the impact preset without awaiting the platform call.
-
jolt(
) → void - Plays the jolt preset without awaiting the platform call.
-
keyboardMechanical(
) → void - Plays the mechanical-keyboard preset without awaiting the platform call.
-
keyboardMembrane(
) → void - Plays the membrane-keyboard preset without awaiting the platform call.
-
knell(
) → void - Plays the knell preset without awaiting the platform call.
-
knock(
) → void - Plays the knock preset without awaiting the platform call.
-
lament(
) → void - Plays the lament preset without awaiting the platform call.
-
latch(
) → void - Plays the latch preset without awaiting the platform call.
-
lighthouse(
) → void - Plays the lighthouse preset without awaiting the platform call.
-
lilt(
) → void - Plays the lilt preset without awaiting the platform call.
-
lock(
) → void - Plays the lock preset without awaiting the platform call.
-
lope(
) → void - Plays the lope preset without awaiting the platform call.
-
march(
) → void - Plays the march preset without awaiting the platform call.
-
metronome(
) → void - Plays the metronome preset without awaiting the platform call.
-
murmur(
) → void - Plays the murmur preset without awaiting the platform call.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
nudge(
) → void - Plays the nudge preset without awaiting the platform call.
-
passingCar(
) → void - Plays the passing-car preset without awaiting the platform call.
-
patter(
) → void - Plays the patter preset without awaiting the platform call.
-
peal(
) → void - Plays the peal preset without awaiting the platform call.
-
peck(
) → void - Plays the peck preset without awaiting the platform call.
-
pendulum(
) → void - Plays the pendulum preset without awaiting the platform call.
-
ping(
) → void - Plays the ping preset without awaiting the platform call.
-
pip(
) → void - Plays the pip preset without awaiting the platform call.
-
piston(
) → void - Plays the piston preset without awaiting the platform call.
-
play(
String name) → void -
Play a preset by its
namestring without awaiting the platform call. -
plink(
) → void - Plays the plink preset without awaiting the platform call.
-
plummet(
) → void - Plays the plummet preset without awaiting the platform call.
-
plunk(
) → void - Plays the plunk preset without awaiting the platform call.
-
poke(
) → void - Plays the poke preset without awaiting the platform call.
-
pound(
) → void - Plays the pound preset without awaiting the platform call.
-
powerDown(
) → void - Plays the power-down preset without awaiting the platform call.
-
propel(
) → void - Plays the propel preset without awaiting the platform call.
-
pulse(
) → void - Plays the pulse preset without awaiting the platform call.
-
pummel(
) → void - Plays the pummel preset without awaiting the platform call.
-
push(
) → void - Plays the push preset without awaiting the platform call.
-
radar(
) → void - Plays the radar preset without awaiting the platform call.
-
rain(
) → void - Plays the rain preset without awaiting the platform call.
-
ramp(
) → void - Plays the ramp preset without awaiting the platform call.
-
rap(
) → void - Plays the rap preset without awaiting the platform call.
-
ratchet(
) → void - Plays the ratchet preset without awaiting the platform call.
-
rebound(
) → void - Plays the rebound preset without awaiting the platform call.
-
ripple(
) → void - Plays the ripple preset without awaiting the platform call.
-
rivet(
) → void - Plays the rivet preset without awaiting the platform call.
-
rustle(
) → void - Plays the rustle preset without awaiting the platform call.
-
shockwave(
) → void - Plays the shockwave preset without awaiting the platform call.
-
snap(
) → void - Plays the snap preset without awaiting the platform call.
-
sonar(
) → void - Plays the sonar preset without awaiting the platform call.
-
spark(
) → void - Plays the spark preset without awaiting the platform call.
-
spin(
) → void - Plays the spin preset without awaiting the platform call.
-
stagger(
) → void - Plays the stagger preset without awaiting the platform call.
-
stamp(
) → void - Plays the stamp preset without awaiting the platform call.
-
stampede(
) → void - Plays the stampede preset without awaiting the platform call.
-
stomp(
) → void - Plays the stomp preset without awaiting the platform call.
-
stoneSkip(
) → void - Plays the stone-skip preset without awaiting the platform call.
-
strike(
) → void - Plays the strike preset without awaiting the platform call.
-
summon(
) → void - Plays the summon preset without awaiting the platform call.
-
surge(
) → void - Plays the surge preset without awaiting the platform call.
-
sway(
) → void - Plays the sway preset without awaiting the platform call.
-
sweep(
) → void - Plays the sweep preset without awaiting the platform call.
-
swell(
) → void - Plays the swell preset without awaiting the platform call.
-
syncopate(
) → void - Plays the syncopate preset without awaiting the platform call.
-
systemCalendarDate(
) → void - Plays the system calendar-date-picker haptic without awaiting the platform call.
-
systemClockTick(
) → void - Plays the system clock-tick haptic without awaiting the platform call.
-
systemConfirm(
) → void - Plays the system confirm haptic without awaiting the platform call.
-
systemContextClick(
) → void - Plays the system context-click haptic without awaiting the platform call.
-
systemDragCrossing(
) → void - Plays the system drag-crossing haptic without awaiting the platform call.
-
systemDragStart(
) → void - Plays the system drag-start haptic without awaiting the platform call.
-
systemEdgeRelease(
) → void - Plays the system edge-release haptic without awaiting the platform call.
-
systemEdgeSqueeze(
) → void - Plays the system edge-squeeze haptic without awaiting the platform call.
-
systemEffectClick(
) → void - Plays the system single-click effect haptic without awaiting the platform call.
-
systemEffectDoubleClick(
) → void - Plays the system double-click effect haptic without awaiting the platform call.
-
systemEffectHeavyClick(
) → void - Plays the system heavy-click effect haptic without awaiting the platform call.
-
systemEffectTick(
) → void - Plays the system tick effect haptic without awaiting the platform call.
-
systemGestureEnd(
) → void - Plays the system gesture-end haptic without awaiting the platform call.
-
systemGestureStart(
) → void - Plays the system gesture-start haptic without awaiting the platform call.
-
systemImpactHeavy(
) → void - Plays the system heavy-impact haptic without awaiting the platform call.
-
systemImpactLight(
) → void - Plays the system light-impact haptic without awaiting the platform call.
-
systemImpactMedium(
) → void - Plays the system medium-impact haptic without awaiting the platform call.
-
systemImpactRigid(
) → void - Plays the system rigid-impact haptic without awaiting the platform call.
-
systemImpactSoft(
) → void - Plays the system soft-impact haptic without awaiting the platform call.
-
systemKeyboardPress(
) → void - Plays the system keyboard-press haptic without awaiting the platform call.
-
systemKeyboardRelease(
) → void - Plays the system keyboard-release haptic without awaiting the platform call.
-
systemKeyboardTap(
) → void - Plays the system keyboard-tap haptic without awaiting the platform call.
-
systemLongPress(
) → void - Plays the system long-press haptic without awaiting the platform call.
-
systemNotificationError(
) → void - Plays the system error-notification haptic without awaiting the platform call.
-
systemNotificationSuccess(
) → void - Plays the system success-notification haptic without awaiting the platform call.
-
systemNotificationWarning(
) → void - Plays the system warning-notification haptic without awaiting the platform call.
-
systemPrimitiveClick(
) → void - Plays the system primitive-click haptic without awaiting the platform call.
-
systemPrimitiveLowTick(
) → void - Plays the system primitive-low-tick haptic without awaiting the platform call.
-
systemPrimitiveQuickFall(
) → void - Plays the system primitive-quick-fall haptic without awaiting the platform call.
-
systemPrimitiveQuickRise(
) → void - Plays the system primitive-quick-rise haptic without awaiting the platform call.
-
systemPrimitiveSlowRise(
) → void - Plays the system primitive-slow-rise haptic without awaiting the platform call.
-
systemPrimitiveSpin(
) → void - Plays the system primitive-spin haptic without awaiting the platform call.
-
systemPrimitiveThud(
) → void - Plays the system primitive-thud haptic without awaiting the platform call.
-
systemPrimitiveTick(
) → void - Plays the system primitive-tick haptic without awaiting the platform call.
-
systemRelease(
) → void - Plays the system release haptic without awaiting the platform call.
-
systemScrollItemFocus(
) → void - Plays the system scroll-item-focus haptic without awaiting the platform call.
-
systemScrollLimit(
) → void - Plays the system scroll-limit haptic without awaiting the platform call.
-
systemScrollTick(
) → void - Plays the system scroll-tick haptic without awaiting the platform call.
-
systemSegmentFrequentTick(
) → void - Plays the system frequent-segment-tick haptic without awaiting the platform call.
-
systemSegmentTick(
) → void - Plays the system segment-tick haptic without awaiting the platform call.
-
systemSelection(
) → void - Plays the system selection-change haptic without awaiting the platform call.
-
systemTextHandleMove(
) → void - Plays the system text-handle-move haptic without awaiting the platform call.
-
systemToggleOff(
) → void - Plays the system toggle-off haptic without awaiting the platform call.
-
systemToggleOn(
) → void - Plays the system toggle-on haptic without awaiting the platform call.
-
systemVirtualKey(
) → void - Plays the system virtual-key haptic without awaiting the platform call.
-
systemVirtualKeyRelease(
) → void - Plays the system virtual-key-release haptic without awaiting the platform call.
-
throb(
) → void - Plays the throb preset without awaiting the platform call.
-
thud(
) → void - Plays the thud preset without awaiting the platform call.
-
thump(
) → void - Plays the thump preset without awaiting the platform call.
-
thunder(
) → void - Plays the thunder preset without awaiting the platform call.
-
thunderRoll(
) → void - Plays the thunder-roll preset without awaiting the platform call.
-
tickTock(
) → void - Plays the tick-tock preset without awaiting the platform call.
-
tidalSurge(
) → void - Plays the tidal-surge preset without awaiting the platform call.
-
tideSwell(
) → void - Plays the tide-swell preset without awaiting the platform call.
-
toString(
) → String -
A string representation of this object.
inherited
-
tremor(
) → void - Plays the tremor preset without awaiting the platform call.
-
trigger(
) → void - Plays the trigger preset without awaiting the platform call.
-
triumph(
) → void - Plays the triumph preset without awaiting the platform call.
-
trumpet(
) → void - Plays the trumpet preset without awaiting the platform call.
-
typewriter(
) → void - Plays the typewriter preset without awaiting the platform call.
-
unfurl(
) → void - Plays the unfurl preset without awaiting the platform call.
-
vortex(
) → void - Plays the vortex preset without awaiting the platform call.
-
wane(
) → void - Plays the wane preset without awaiting the platform call.
-
warDrum(
) → void - Plays the war-drum preset without awaiting the platform call.
-
waterfall(
) → void - Plays the waterfall preset without awaiting the platform call.
-
wave(
) → void - Plays the wave preset without awaiting the platform call.
-
wisp(
) → void - Plays the wisp preset without awaiting the platform call.
-
wobble(
) → void - Plays the wobble preset without awaiting the platform call.
-
woodpecker(
) → void - Plays the woodpecker preset without awaiting the platform call.
-
zipper(
) → void - Plays the zipper preset without awaiting the platform call.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited