AdaptivePresetPattern class final
An AdaptivePresetConfig that plays a PatternData pattern.
- Inheritance
-
- Object
- AdaptivePresetConfig
- AdaptivePresetPattern
Constructors
- AdaptivePresetPattern(PatternData pattern)
-
Creates an AdaptivePresetPattern with the given
pattern.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pattern → PatternData
-
The PatternData played when AdaptiveHaptics.play is called.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited