PatternData class
Full haptic pattern combining a continuous curve and discrete events.
Constructors
-
PatternData({required ContinuousPattern continuousPattern, required List<
DiscretePoint> discretePattern}) -
Creates a PatternData from a
continuousPatternand a list ofdiscretePatternevents.const -
PatternData.fromArrays({required List<
List< amplitude, required List<double> >List< frequency, required List<double> >List< discrete})double> > -
Raw array constructor matching the native iOS/Android shorthand:
factory
Properties
- continuousPattern → ContinuousPattern
-
The continuous (envelope) portion of the pattern.
final
-
discretePattern
→ List<
DiscretePoint> -
The list of discrete haptic events layered on top of the continuous curve.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited